@@ -22,10 +22,27 @@ from googlecloudsdk.calliope import arg_parsers
 
 
 def AddPlatformVersion(parser, required=True):
+  """Adds platform version flag.
+
+  Args:
+    parser: The argparse.parser to add the arguments to.
+    required: Indicates if the flag is required.
+  """
+
+  help_text = """
+Platform version to use for the cluster.
+
+To retrieve a list of valid versions, run:
+
+  $ gcloud alpha container attached get-server-config --location=LOCATION
+
+Replace ``LOCATION'' with the target Google Cloud location for the cluster.
+"""
+
   parser.add_argument(
       '--platform-version',
       required=required,
-      help='Platform version to use for the cluster.')
+      help=help_text)
 
 
 def GetPlatformVersion(args):
@@ -53,18 +70,39 @@ def GetOidcJwks(args):
   return getattr(args, 'oidc_jwks', None)
 
 
-def AddAuthority(parser):
-  """Adds Authority flags.
+def AddHasPrivateIssuer(parser):
+  help_text = """Indicates no publicly routable OIDC discovery endpoint exists
+for the Kubernetes service account token issuer.
+
+If this flag is set, gcloud will read the issuer URL and JWKs from the cluster's
+api server.
+"""
+  parser.add_argument(
+      '--has-private-issuer', help=help_text, action='store_true')
+
+
+def GetHasPrivateIssuer(args):
+  return getattr(args, 'has_private_issuer', None)
+
+
+def AddOidcConfig(parser):
+  """Adds Oidc Config flags.
 
   Args:
     parser: The argparse.parser to add the arguments to.
   """
 
-  group = parser.add_group('Authority', required=True)
+  group = parser.add_group('OIDC config', required=True)
   AddIssuerUrl(group, required=True)
   AddOidcJwks(group)
 
 
+def AddRegisterOidcConfig(parser):
+  group = parser.add_mutually_exclusive_group('OIDC config', required=True)
+  AddIssuerUrl(group)
+  AddHasPrivateIssuer(group)
+
+
 def AddDistribution(parser, required=False):
   help_text = """
 Set the base platform type of the cluster to attach.
@@ -105,3 +143,30 @@ def GetAdminUsers(args):
   if args.admin_users:
     return args.admin_users
   return None
+
+
+def AddKubectl(parser):
+  group = parser.add_group('kubectl config', required=True)
+  AddKubeconfig(group)
+  AddContext(group)
+
+
+def AddKubeconfig(parser):
+  help_txt = """Path to the kubeconfig file.
+
+If not provided, the default at ~/.kube/config will be used.
+"""
+  parser.add_argument('--kubeconfig', help=help_txt)
+
+
+def GetKubeconfig(args):
+  return getattr(args, 'kubeconfig', None)
+
+
+def AddContext(parser):
+  help_txt = """Context to use in the kubeconfig."""
+  parser.add_argument('--context', required=True, help=help_txt)
+
+
+def GetContext(args):
+  return getattr(args, 'context', None)
