@@ -95,36 +95,47 @@ _INSTANCE_TYPE_MAPPER = arg_utils.ChoiceEnumMapper(
     apis.GetMessagesModule(
         'spanner',
         'v1').Instance.InstanceTypeValueValuesEnum,
-    help_str='The type of this instance.',
+    help_str='Specifies the type for this instance.',
     required=False,
     custom_mappings={
         'PROVISIONED': (
             'provisioned',
             ('Provisioned instances have dedicated resources, standard usage '
-             'limits and support')),
+             'limits, and support.')),
         'FREE_INSTANCE': (
             'free-instance',
-            ('Free instances provide no guarantee for dedicated resources, '
-             '[node_count, processing_units] should be 0. They come with '
-             'stricter usage limits and limited support.')),
+            ('Free trial instances provide no guarantees for dedicated '
+             'resources, both node_count and processing_units should be 0. '
+             'They come with stricter usage limits and limited support.')),
+    })
+
+_DEFAULT_STORAGE_TYPE_MAPPER = arg_utils.ChoiceEnumMapper(
+    '--default-storage-type',
+    apis.GetMessagesModule('spanner',
+                           'v1').Instance.DefaultStorageTypeValueValuesEnum,
+    help_str='Specifies the default storage type for this instance.',
+    required=False,
+    custom_mappings={
+        'SSD': ('ssd', ('Use ssd as default storage type for this instance')),
+        'HDD': ('hdd', ('Use hdd as default storage type for this instance')),
     })
 
 _EXPIRE_BEHAVIOR_MAPPER = arg_utils.ChoiceEnumMapper(
     '--expire-behavior',
     apis.GetMessagesModule(
-        'spanner',
-        'v1').FreeInstanceMetadata.ExpireBehaviorValueValuesEnum,
-    help_str='The expire behavior of a free instance.',
+        'spanner', 'v1').FreeInstanceMetadata.ExpireBehaviorValueValuesEnum,
+    help_str='The expire behavior of a free trial instance.',
     required=False,
     custom_mappings={
-        'FREE_TO_PROVISIONED': (
-            'free-to-provisioned',
-            ('When the free instance expires, upgrade the instance to a '
-             'provisioned instance')),
-        'REMOVE_AFTER_GRACE_PERIOD': (
-            'remove-after-grace-period',
-            ('When the free instance expires, disable the instance, and delete '
-             'it after the grace period passes if it has not been upgraded.')),
+        'FREE_TO_PROVISIONED':
+            ('free-to-provisioned',
+             ('When the free trial instance expires, upgrade the instance to a '
+              'provisioned instance.')),
+        'REMOVE_AFTER_GRACE_PERIOD':
+            ('remove-after-grace-period',
+             ('When the free trial instance expires, disable the instance, '
+              'and delete it after the grace period passes if it has not been '
+              'upgraded to a provisioned instance.')),
     })
 
 
@@ -420,6 +431,15 @@ def GetInstanceType(args):
   return _INSTANCE_TYPE_MAPPER.GetEnumForChoice(args.instance_type)
 
 
+def AddDefaultStorageTypeArg(parser):
+  return _DEFAULT_STORAGE_TYPE_MAPPER.choice_arg.AddToParser(parser)
+
+
+def GetDefaultStorageTypeArg(args):
+  return _DEFAULT_STORAGE_TYPE_MAPPER.GetEnumForChoice(
+      args.default_storage_type)
+
+
 def AddExpireBehaviorArg(parser):
   return _EXPIRE_BEHAVIOR_MAPPER.choice_arg.AddToParser(parser)
 
