@@ -23,7 +23,7 @@ from googlecloudsdk.command_lib.storage.resources import shim_format_util
 
 _BUCKET_DISPLAY_TITLES_AND_DEFAULTS = (
     base.BucketDisplayTitlesAndDefaults(
-        storage_class=base.FieldDisplayTitleAndDefault(
+        default_storage_class=base.FieldDisplayTitleAndDefault(
             title='Storage class', default=None),
         location_type=base.FieldDisplayTitleAndDefault(
             title='Location type', default=None),
@@ -61,11 +61,9 @@ _BUCKET_DISPLAY_TITLES_AND_DEFAULTS = (
             title='Time updated', default=None),
         metageneration=base.FieldDisplayTitleAndDefault(
             title='Metageneration', default=None),
-        bucket_policy_only_enabled=base.FieldDisplayTitleAndDefault(
-            title='Bucket Policy Only enabled',
-            default=None,
-            field_name='_bucket_policy_only_enabled'),
-        satisifes_pzs=base.FieldDisplayTitleAndDefault(
+        uniform_bucket_level_access=base.FieldDisplayTitleAndDefault(
+            title='Bucket Policy Only enabled', default=None),
+        satisfies_pzs=base.FieldDisplayTitleAndDefault(
             title='Satisfies PZS', default=None),
         acl=base.FieldDisplayTitleAndDefault(
             title='ACL', default=shim_format_util.EMPTY_LIST_STRING),
@@ -98,7 +96,7 @@ _OBJECT_DISPLAY_TITLES_AND_DEFAULTS = (
             title='Content-Encoding', default=None),
         content_language=base.FieldDisplayTitleAndDefault(
             title='Content-Language', default=None),
-        content_length=base.FieldDisplayTitleAndDefault(
+        size=base.FieldDisplayTitleAndDefault(
             title='Content-Length', default=shim_format_util.NONE_STRING),
         content_type=base.FieldDisplayTitleAndDefault(
             title='Content-Type', default=shim_format_util.NONE_STRING),
@@ -108,7 +106,7 @@ _OBJECT_DISPLAY_TITLES_AND_DEFAULTS = (
             title='Custom-Time', default=None),
         noncurrent_time=base.FieldDisplayTitleAndDefault(
             title='Noncurrent time', default=None),
-        additional_properties=base.FieldDisplayTitleAndDefault(
+        custom_metadata=base.FieldDisplayTitleAndDefault(
             title='Metadata', default=None),
         crc32c_hash=base.FieldDisplayTitleAndDefault(
             title='Hash (crc32c)', default=None),
@@ -116,7 +114,7 @@ _OBJECT_DISPLAY_TITLES_AND_DEFAULTS = (
             title='Hash (md5)', default=None),
         encryption_algorithm=base.FieldDisplayTitleAndDefault(
             title='Encryption algorithm', default=None),
-        encryption_key_sha256=base.FieldDisplayTitleAndDefault(
+        decryption_key_hash=base.FieldDisplayTitleAndDefault(
             title='Encryption key SHA256', default=None),
         etag=base.FieldDisplayTitleAndDefault(
             title='ETag', default=shim_format_util.NONE_STRING),
@@ -132,30 +130,28 @@ _OBJECT_DISPLAY_TITLES_AND_DEFAULTS = (
 class GsutilFullResourceFormatter(base.FullResourceFormatter):
   """Format a resource as per gsutil Storage style for ls -L output."""
 
-  def format_bucket(self, url, displayable_bucket_data):
+  def format_bucket(self, url, bucket_resource):
     """See super class."""
     shim_format_util.replace_time_values_with_gsutil_style_strings(
-        displayable_bucket_data)
-    shim_format_util.replace_bucket_values_with_present_string(
-        displayable_bucket_data)
-    return base.get_formatted_string(url, displayable_bucket_data,
+        bucket_resource)
+    shim_format_util.replace_bucket_values_with_present_string(bucket_resource)
+    return base.get_formatted_string(url, bucket_resource,
                                      _BUCKET_DISPLAY_TITLES_AND_DEFAULTS)
 
   def format_object(self,
                     url,
-                    displayable_object_data,
+                    object_resource,
                     show_acl=True,
                     show_version_in_url=False):
     """See super class."""
     shim_format_util.replace_time_values_with_gsutil_style_strings(
-        displayable_object_data)
+        object_resource)
     shim_format_util.replace_object_values_with_encryption_string(
-        displayable_object_data, 'encrypted')
-    shim_format_util.reformat_custom_metadata_for_gsutil(
-        displayable_object_data)
+        object_resource, 'encrypted')
+    shim_format_util.reformat_custom_metadata_for_gsutil(object_resource)
     return base.get_formatted_string(
         url,
-        displayable_object_data,
+        object_resource,
         _OBJECT_DISPLAY_TITLES_AND_DEFAULTS,
         show_acl=show_acl,
         show_version_in_url=show_version_in_url)
