@@ -19,6 +19,7 @@ from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.container.gkemulticloud import aws as api_util
+from googlecloudsdk.api_lib.container.gkemulticloud import util
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.container.aws import resource_args
 from googlecloudsdk.command_lib.container.gkemulticloud import endpoint_util
@@ -33,7 +34,8 @@ class GetCredentials(base.Command):
 
   detailed_help = {
       'EXAMPLES': kubeconfig.COMMAND_EXAMPLE,
-      'DESCRIPTION': kubeconfig.COMMAND_DESCRIPTION.format(kind='AWS')
+      'DESCRIPTION': kubeconfig.COMMAND_DESCRIPTION.format(
+          cluster_type='Anthos cluster on AWS')
   }
 
   @staticmethod
@@ -54,7 +56,8 @@ class GetCredentials(base.Command):
                                             cluster_ref)
       log.status.Print('Fetching cluster endpoint and auth data.')
       resp = cluster_client.Get(cluster_ref)
-      if resp.state != 'RUNNING':
+      if resp.state != util.GetMessagesModule(
+      ).GoogleCloudGkemulticloudV1AwsCluster.StateValueValuesEnum.RUNNING:
         log.warning(
             kubeconfig.NOT_RUNNING_MSG.format(cluster_ref.awsClustersId))
       kubeconfig.ValidateClusterVersion(resp, cluster_ref.awsClustersId)
