@@ -64,6 +64,9 @@ class Create(base.CreateCommand):
     flags.AddProxyConfig(parser)
     flags.AddFleetProject(parser)
     flags.AddAdminUsers(parser)
+    flags.AddDescription(parser)
+    flags.AddAnnotations(parser)
+    flags.AddLogging(parser)
     base.ASYNC_FLAG.AddToParser(parser)
     parser.display_info.AddFormat(constants.AZURE_CLUSTERS_FORMAT)
 
@@ -94,4 +97,4 @@ class CreateAlpha(Create):
   def Args(parser, track=base.ReleaseTrack.ALPHA):
     """Registers alpha track flags for this command."""
     Create.Args(parser)
-    flags.AddLogging(parser)
+    flags.AddMonitoringConfig(parser)
