@@ -48,6 +48,9 @@ class Update(base.UpdateCommand):
     flags.AddAdminUsers(parser, create=False)
     flags.AddSSHPublicKey(parser, required=False)
     flags.AddValidateOnly(parser, 'update of the cluster')
+    flags.AddDescriptionForUpdate(parser)
+    flags.AddAnnotationsForUpdate(parser, 'cluster')
+    flags.AddLogging(parser)
     base.ASYNC_FLAG.AddToParser(parser)
     parser.display_info.AddFormat(constants.AZURE_CLUSTERS_FORMAT)
 
@@ -75,4 +78,3 @@ class UpdateAlpha(Update):
   def Args(parser, track=base.ReleaseTrack.ALPHA):
     """Registers alpha track flags for this command."""
     Update.Args(parser)
-    flags.AddLogging(parser)
