@@ -44,14 +44,7 @@ class Upgrade(base.UpdateCommand):
 
   @classmethod
   def Args(cls, parser):
-    if resources.UseRegionalMemberships(cls.ReleaseTrack()):
-      resources.AddMembershipResourceArg(parser)
-    else:
-      parser.add_argument(
-          '--membership',
-          type=str,
-          help='The Membership name provided during registration.',
-      )
+    resources.AddMembershipResourceArg(parser)
     parser.add_argument(
         '--version',
         type=str,
@@ -61,14 +54,9 @@ class Upgrade(base.UpdateCommand):
   def Run(self, args):
     f = self.GetFeature()
     new_version = args.version
-    if resources.UseRegionalMemberships(self.ReleaseTrack()):
-      membership = base.ParseMembership(
-          args, prompt=True, autoselect=True, search=True)
-      _, cluster_v = utils.versions_for_member(f, membership)
-    else:
-      membership = _get_or_prompt_membership(args.membership)
-      _, cluster_v = utils.versions_for_member(
-          f, self.MembershipResourceName(membership))
+    membership = base.ParseMembership(
+        args, prompt=True, autoselect=True, search=True)
+    _, cluster_v = utils.versions_for_member(f, membership)
 
     if not self._validate_versions(membership, cluster_v, new_version):
       return
@@ -81,24 +69,15 @@ class Upgrade(base.UpdateCommand):
 
     patch = self.messages.MembershipFeatureSpec()
     # If there's an existing spec, copy it to leave the other fields intact.
-    if resources.UseRegionalMemberships(self.ReleaseTrack()):
-      for full_name, spec in self.hubclient.ToPyDict(f.membershipSpecs).items():
-        if util.MembershipPartialName(full_name) == util.MembershipPartialName(
-            membership) and spec is not None:
-          patch = spec
-    else:
-      for full_name, spec in self.hubclient.ToPyDict(f.membershipSpecs).items():
-        if util.MembershipShortname(
-            full_name) == membership and spec is not None:
-          patch = spec
+    for full_name, spec in self.hubclient.ToPyDict(f.membershipSpecs).items():
+      if util.MembershipPartialName(full_name) == util.MembershipPartialName(
+          membership) and spec is not None:
+        patch = spec
     if patch.configmanagement is None:
       patch.configmanagement = self.messages.ConfigManagementMembershipSpec()
     patch.configmanagement.version = new_version
 
-    if resources.UseRegionalMemberships(self.ReleaseTrack()):
-      membership_key = membership
-    else:
-      membership_key = self.MembershipResourceName(membership)
+    membership_key = membership
     f = self.messages.Feature(
         membershipSpecs=self.hubclient.ToMembershipSpecs(
             {membership_key: patch}))
