@@ -71,23 +71,22 @@ class GetCredentials(base.Command):
         help=textwrap.dedent("""\
           The membership name used to locate a cluster in your project. """),
     )
-    if cls.ReleaseTrack() is base.ReleaseTrack.ALPHA:
-      parser.add_argument(
-          '--location',
-          type=str,
-          hidden=True,
-          help=textwrap.dedent("""\
-              The location for the membership resource, e.g. `us-central1`.
-              If not specified, defaults to `global`.
-            """),
-      )
+    # TODO(b/255818709): When this becomes unhidden, add a regional example
+    # above.
+    parser.add_argument(
+        '--location',
+        type=str,
+        hidden=True,
+        help=textwrap.dedent("""\
+            The location for the membership resource, e.g. `us-central1`.
+            If not specified, defaults to `global`.
+          """),
+    )
 
   def Run(self, args):
     container_util.CheckKubectlInstalled()
     project_id = properties.VALUES.core.project.GetOrFail()
-    location = getattr(args, 'location', 'global')
-    if location is None:
-      location = 'global'
+    location = args.location or 'global'
 
     log.status.Print('Starting to build Gateway kubeconfig...')
     log.status.Print('Current project_id: ' + project_id)
@@ -104,18 +103,17 @@ class GetCredentials(base.Command):
     membership = self.ReadClusterMembership(project_id, location,
                                             args.MEMBERSHIP)
 
+    # Registered GKE clusters use a different URL scheme, having
+    # `gkeMemberships/` rather than the standard `memberships/` resource type.
     resource_type = 'memberships'
-    # Change the URL for registered GKE clusters
-    if self.ReleaseTrack() is base.ReleaseTrack.ALPHA or self.ReleaseTrack(
-    ) is base.ReleaseTrack.BETA:
-      # Probers use GKE clusters to emulate attached clusters, and so must be
-      # exempt.
-      if project_id == 'gkeconnect-prober':
-        pass
-      elif (hasattr(membership, 'endpoint') and
-            hasattr(membership.endpoint, 'gkeCluster') and
-            membership.endpoint.gkeCluster):
-        resource_type = 'gkeMemberships'
+    # Probers use GKE clusters to emulate attached clusters, and so must be
+    # exempt from this.
+    if project_id == 'gkeconnect-prober':
+      pass
+    elif (hasattr(membership, 'endpoint') and
+          hasattr(membership.endpoint, 'gkeCluster') and
+          membership.endpoint.gkeCluster):
+      resource_type = 'gkeMemberships'
 
     self.GenerateKubeconfig(
         util.GetConnectGatewayServiceName(hub_endpoint_override, location),
