@@ -34,7 +34,6 @@ DETAILED_HELP = {
 }
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
 class List(base.ListCommand):
   """Lists the defined buckets."""
 
@@ -48,8 +47,8 @@ class List(base.ListCommand):
         'locations will be listed')
     parser.display_info.AddFormat(
         'table(name.segment(-3):label=LOCATION, '
-        'name.segment(-1):label=BUCKET_ID, retentionDays, lifecycle_state, '
-        'locked, create_time, update_time)')
+        'name.segment(-1):label=BUCKET_ID, retentionDays, restrictedFields, '
+        'indexConfigs, lifecycle_state, locked, create_time, update_time)')
     parser.display_info.AddCacheUpdater(None)
 
   def Run(self, args):
@@ -68,19 +67,4 @@ class List(base.ListCommand):
     for bucket in result.buckets:
       yield bucket
 
-
-# pylint: disable=missing-docstring
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class ListAlpha(List):
-  __doc__ = List.__doc__
-
-  @staticmethod
-  def Args(parser):
-    List.Args(parser)
-    parser.display_info.AddFormat(
-        'table(name.segment(-3):label=LOCATION, '
-        'name.segment(-1):label=BUCKET_ID, retentionDays, restrictedFields, '
-        'indexConfigs, lifecycle_state, locked, create_time, update_time)')
-
-
 List.detailed_help = DETAILED_HELP
