@@ -23,6 +23,7 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.run import commands
 from googlecloudsdk.command_lib.run import connection_context
 from googlecloudsdk.command_lib.run import flags
+from googlecloudsdk.command_lib.run import platforms
 from googlecloudsdk.command_lib.run import pretty_print
 from googlecloudsdk.command_lib.run import resource_args
 from googlecloudsdk.command_lib.run import serverless_operations
@@ -66,13 +67,18 @@ class List(commands.List):
   def Args(cls, parser):
     cls.CommonArgs(parser)
 
-  def _SetFormat(self, args, show_region=False, show_namespace=False):
+  def _SetFormat(self,
+                 args,
+                 show_region=False,
+                 show_namespace=False,
+                 show_description=False):
     """Set display format for output.
 
     Args:
       args: Namespace, the args namespace
       show_region: bool, True to show region of listed services
       show_namespace: bool, True to show namespace of listed services
+      show_description: bool, True to show description of listed services
     """
     columns = [
         pretty_print.READY_COLUMN,
@@ -82,6 +88,8 @@ class List(commands.List):
       columns.append('region:label=REGION')
     if show_namespace:
       columns.append('namespace:label=NAMESPACE')
+    if show_description:
+      columns.append('description:label=DESCRIPTION')
     columns.extend([
         'domain:label=URL',
         'last_modifier:label="LAST DEPLOYED BY"',
@@ -92,7 +100,7 @@ class List(commands.List):
 
   def Run(self, args):
     """List available services."""
-    is_managed = flags.GetPlatform() == flags.PLATFORM_MANAGED
+    is_managed = platforms.GetPlatform() == platforms.PLATFORM_MANAGED
     if is_managed and not args.IsSpecified('region'):
       self._SetFormat(args, show_region=True)
       client = global_methods.GetServerlessClientInstance()
@@ -109,14 +117,18 @@ class List(commands.List):
       with serverless_operations.Connect(conn_context) as client:
         self.SetCompleteApiEndpoint(conn_context.endpoint)
         if not is_managed:
-          location_msg = ' in [{}]'.format(conn_context.cluster_location)
-          project_msg = ' in project [{}]'.format(conn_context.cluster_project)
+          is_gke = platforms.GetPlatform() == platforms.PLATFORM_GKE
+          location_msg = ' in [{}]'.format(
+              conn_context.cluster_location) if is_gke else ''
           is_multi_tenant = conn_context.cluster_project != properties.VALUES.core.project.Get(
               required=False)
+          project_msg = ' in project [{}]'.format(
+              conn_context.cluster_project
+          ) if is_gke and is_multi_tenant else ''
           log.status.Print('For cluster [{cluster}]{zone}{project}:'.format(
               cluster=conn_context.cluster_name,
-              zone=location_msg if conn_context.cluster_location else '',
-              project=project_msg if is_multi_tenant else ''))
+              zone=location_msg,
+              project=project_msg))
         return commands.SortByName(client.ListServices(namespace_ref))
 
 
@@ -128,4 +140,5 @@ class AlphaList(List):
   def Args(cls, parser):
     cls.CommonArgs(parser)
 
+
 AlphaList.__doc__ = List.__doc__
