@@ -18,17 +18,15 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
-from googlecloudsdk.api_lib.cloudbuild import logs as logs_util
-from googlecloudsdk.api_lib.logging.formatter import FormatLog
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.logs import read as read_logs_lib
 from googlecloudsdk.command_lib.run import flags
-from googlecloudsdk.core import log
+from googlecloudsdk.command_lib.run import streaming
 from googlecloudsdk.core import properties
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class Tail(base.Command):
+class Tail(base.BinaryBackedCommand):
   """Tail logs for a service."""
 
   detailed_help = {
@@ -38,16 +36,18 @@ class Tail(base.Command):
           Cloud Run service in real time.  The log entries are formatted for
           consumption in a terminal.
           """,
-      'SYNOPSIS':
+      'EXAMPLES':
           """\
-          {command} (SERVICE)
-          """,
-      'FLAGS':
-          """\
-          --region=REGION
-          Region of the Cloud Run service.
-          If not specified, will take its value from the gcloud property
-          "run/region" or prompt.
+          To tail log entries for a Cloud Run Service, run:
+
+            $ {command} my-service
+
+          To tail log entries with severity ERROR or higher, run:
+
+            $ {command} my-service --log-filter="severity>=ERROR"
+
+          Detailed information about filters can be found at:
+          [](https://cloud.google.com/logging/docs/view/advanced_filters)
           """,
   }
 
@@ -59,19 +59,15 @@ class Tail(base.Command):
   def Run(self, args):
     filters = []
     if args.IsSpecified('log_filter'):
-      filters.append(args.log_filter + ' \n')
-    filters.append('resource.type = %s \n' % 'cloud_run_revision')
-    filters.append('resource.labels.service_name = %s \n' % args.service)
-    filters.append('resource.labels.location = %s \n' %
-                   flags.GetRegion(args, prompt=False))
-    filters.append('severity >= DEFAULT')
-    parent = 'projects/{project_id}'.format(
-        project_id=properties.VALUES.core.project.Get(required=True))
-    filter_str = ''.join(str(filter) for filter in filters)
-    tailer = logs_util.GetGCLLogTailer()
-    logs = tailer.TailLogs([parent], filter_str)
-
-    for log_line in logs:
-      output_log = FormatLog(log_line)
-      if output_log:
-        log.out.Print(output_log)
+      filters.append(args.log_filter)
+    filters.append('resource.type=%s' % 'cloud_run_revision')
+    filters.append('resource.labels.service_name=%s' % args.service)
+    filters.append('resource.labels.location=%s' %
+                   flags.GetRegion(args, prompt=True))
+    filters.append('severity>=DEFAULT')
+    project_id = properties.VALUES.core.project.Get(required=True)
+    filter_str = ' '.join(filters)
+    command_executor = streaming.LogStreamingWrapper()
+    response = command_executor(
+        project_id=project_id, log_format='run', log_filter=filter_str)
+    return self._DefaultOperationResponseHandler(response)
