@@ -36,6 +36,7 @@ from gslib.command_runner import CommandRunner
 from gslib.cs_api_map import ApiMapConstants
 from gslib.cs_api_map import ApiSelector
 from gslib.discard_messages_queue import DiscardMessagesQueue
+from gslib.gcs_json_api import GcsJsonApi
 from gslib.tests.mock_logging_handler import MockLoggingHandler
 from gslib.tests.testcase import base
 import gslib.tests.util as util
@@ -45,6 +46,21 @@ from gslib.utils.constants import UTF8
 from gslib.utils.text_util import print_to_fd
 
 
+def _AttemptToCloseSysFd(fd):
+  """Suppress IOError when closing sys.stdout or sys.stderr in tearDown."""
+  # In PY2, if another sibling thread/process tried closing it at the same
+  # time we did, it succeeded either way, so we just continue. This approach
+  # was taken from https://github.com/pytest-dev/pytest/pull/3305.
+  if not six.PY2:  # This doesn't happen in PY3, AFAICT.
+    fd.close()
+    return
+
+  try:
+    fd.close()
+  except IOError:
+    pass
+
+
 class GsutilApiUnitTestClassMapFactory(object):
   """Class map factory for use in unit tests.
 
@@ -56,8 +72,12 @@ class GsutilApiUnitTestClassMapFactory(object):
   def GetClassMap(cls):
     """Returns a class map for use in unit tests."""
     gs_class_map = {
-        ApiSelector.XML: BotoTranslation,
-        ApiSelector.JSON: BotoTranslation
+        ApiSelector.XML:
+            BotoTranslation,
+        # TODO: This should be replaced with 'ApiSelector.JSON: GcsJsonApi'.
+        # Refer Issue https://github.com/GoogleCloudPlatform/gsutil/issues/970
+        ApiSelector.JSON:
+            BotoTranslation
     }
     s3_class_map = {ApiSelector.XML: BotoTranslation}
     class_map = {'gs': gs_class_map, 's3': s3_class_map}
@@ -87,10 +107,18 @@ class GsUtilUnitTestCase(base.GsUtilTestCase):
     self.stdout_save = sys.stdout
     self.stderr_save = sys.stderr
     fd, self.stdout_file = tempfile.mkstemp()
-    sys.stdout = os.fdopen(fd, 'wb+')
+    # Specify the encoding explicitly to ensure Windows uses 'utf-8' instead of
+    # the default of 'cp1252'.
+    if six.PY2:
+      sys.stdout = os.fdopen(fd, 'w+')
+    else:
+      sys.stdout = os.fdopen(fd, 'w+', encoding='utf-8')
     fd, self.stderr_file = tempfile.mkstemp()
     # do not set sys.stderr to be 'wb+' - it will blow up the logger
-    sys.stderr = os.fdopen(fd, 'w+')
+    if six.PY2:
+      sys.stderr = os.fdopen(fd, 'w+')
+    else:
+      sys.stderr = os.fdopen(fd, 'w+', encoding='utf-8')
     self.accumulated_stdout = []
     self.accumulated_stderr = []
 
@@ -133,8 +161,8 @@ class GsUtilUnitTestCase(base.GsUtilTestCase):
     stderr = six.ensure_text(get_utf8able_str(stderr))
     stdout += ''.join(self.accumulated_stdout)
     stderr += ''.join(self.accumulated_stderr)
-    sys.stdout.close()
-    sys.stderr.close()
+    _AttemptToCloseSysFd(sys.stdout)
+    _AttemptToCloseSysFd(sys.stderr)
     sys.stdout = self.stdout_save
     sys.stderr = self.stderr_save
     os.unlink(self.stdout_file)
@@ -189,7 +217,7 @@ class GsUtilUnitTestCase(base.GsUtilTestCase):
       One or a tuple of requested return values, depending on whether
       return_stdout, return_stderr, and/or return_log_handler were specified.
       Return Types:
-        stdout - binary
+        stdout - str (binary in Py2, text in Py3)
         stderr - str (binary in Py2, text in Py3)
         log_handler - MockLoggingHandler
     """
@@ -242,8 +270,8 @@ class GsUtilUnitTestCase(base.GsUtilTestCase):
         except UnicodeDecodeError:
           sys.stdout.seek(0)
           sys.stderr.seek(0)
-          stdout = sys.stdout.buffer.read().decode(UTF8)
-          stderr = sys.stderr.buffer.read().decode(UTF8)
+          stdout = sys.stdout.buffer.read()
+          stderr = sys.stderr.buffer.read()
       logging.getLogger(command_name).removeHandler(mock_log_handler)
       mock_log_handler.close()
 
@@ -312,7 +340,7 @@ class GsUtilUnitTestCase(base.GsUtilTestCase):
                              debug=debug)
 
   @classmethod
-  def _test_wildcard_iterator(cls, uri_or_str, debug=0):
+  def _test_wildcard_iterator(cls, uri_or_str, exclude_pattern=None, debug=0):
     """Convenience method for instantiating a test instance of WildcardIterator.
 
     This makes it unnecessary to specify all the params of that class
@@ -325,6 +353,7 @@ class GsUtilUnitTestCase(base.GsUtilTestCase):
 
     Args:
       uri_or_str: StorageUri or string representing the wildcard string.
+      exclude_pattern: For FileUrls, regex of paths to ignore during iteration.
       debug: debug level to pass to the underlying connection (0..3)
 
     Returns:
@@ -335,8 +364,8 @@ class GsUtilUnitTestCase(base.GsUtilTestCase):
     if hasattr(uri_or_str, 'uri'):
       uri_string = uri_or_str.uri
 
-    return wildcard_iterator.CreateWildcardIterator(uri_string,
-                                                    cls.MakeGsUtilApi())
+    return wildcard_iterator.CreateWildcardIterator(
+        uri_string, cls.MakeGsUtilApi(debug), exclude_pattern=exclude_pattern)
 
   @staticmethod
   def _test_storage_uri(uri_str, default_scheme='file', debug=0, validate=True):
